@@ -1,4 +1,4 @@
-/* The GIMP -- an image manipulation program
+/* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * gimpdialogfactory.c
@@ -50,17 +50,6 @@
 #endif
 
 
-typedef enum
-{
-  GIMP_DIALOG_SHOW_ALL,
-  GIMP_DIALOG_HIDE_ALL,
-  GIMP_DIALOG_SHOW_TOOLBOX
-} GimpDialogShowState;
-
-
-static void   gimp_dialog_factory_class_init (GimpDialogFactoryClass *klass);
-static void   gimp_dialog_factory_init       (GimpDialogFactory      *factory);
-
 static void   gimp_dialog_factory_dispose             (GObject           *object);
 static void   gimp_dialog_factory_finalize            (GObject           *object);
 
@@ -68,7 +57,7 @@ static GtkWidget *
               gimp_dialog_factory_default_constructor (GimpDialogFactory *factory,
                                                        GimpDialogFactoryEntry *entry,
                                                        GimpContext       *context,
-                                                       gint               preview_size);
+                                                       gint               view_size);
 static void     gimp_dialog_factory_set_widget_data   (GtkWidget         *dialog,
                                                        GimpDialogFactory *factory,
                                                        GimpDialogFactoryEntry *entry);
@@ -100,46 +89,21 @@ static void   gimp_dialog_factories_unset_busy_foreach(gconstpointer      key,
                                                        GimpDialogFactory *factory,
                                                        gpointer           data);
 
-
-static GimpObjectClass *parent_class = NULL;
+static GtkWidget *
+              gimp_dialog_factory_get_toolbox     (GimpDialogFactory *toolbox_factory);
 
 
-GType
-gimp_dialog_factory_get_type (void)
-{
-  static GType factory_type = 0;
+G_DEFINE_TYPE (GimpDialogFactory, gimp_dialog_factory, GIMP_TYPE_OBJECT)
 
-  if (! factory_type)
-    {
-      static const GTypeInfo factory_info =
-      {
-        sizeof (GimpDialogFactoryClass),
-        NULL,           /* base_init */
-        NULL,           /* base_finalize */
-        (GClassInitFunc) gimp_dialog_factory_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (GimpDialogFactory),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) gimp_dialog_factory_init,
-      };
+#define parent_class gimp_dialog_factory_parent_class
 
-      factory_type = g_type_register_static (GIMP_TYPE_OBJECT,
-                                             "GimpDialogFactory",
-                                             &factory_info, 0);
-    }
+static gboolean dialogs_shown = TRUE;  /* FIXME */
 
-  return factory_type;
-}
 
 static void
 gimp_dialog_factory_class_init (GimpDialogFactoryClass *klass)
 {
-  GObjectClass *object_class;
-
-  object_class = G_OBJECT_CLASS (klass);
-
-  parent_class = g_type_class_peek_parent (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->dispose  = gimp_dialog_factory_dispose;
   object_class->finalize = gimp_dialog_factory_finalize;
@@ -161,10 +125,9 @@ gimp_dialog_factory_init (GimpDialogFactory *factory)
 static void
 gimp_dialog_factory_dispose (GObject *object)
 {
-  GimpDialogFactory *factory;
+  GimpDialogFactory *factory = GIMP_DIALOG_FACTORY (object);
   GList             *list;
-
-  factory = GIMP_DIALOG_FACTORY (object);
+  gpointer           key;
 
   /*  start iterating from the beginning each time we destroyed a
    *  toplevel because destroying a dock may cause lots of items
@@ -192,32 +155,48 @@ gimp_dialog_factory_dispose (GObject *object)
         }
     }
 
+  if (factory->open_dialogs)
+    {
+      g_list_free (factory->open_dialogs);
+      factory->open_dialogs = NULL;
+    }
+
+  if (factory->session_infos)
+    {
+      g_list_foreach (factory->session_infos, (GFunc) gimp_session_info_free,
+                      NULL);
+      g_list_free (factory->session_infos);
+      factory->session_infos = NULL;
+    }
+
+  if (strcmp (GIMP_OBJECT (factory)->name, "toolbox") == 0)
+    key = "";
+  else
+    key = GIMP_OBJECT (factory)->name;
+
+  g_hash_table_remove (GIMP_DIALOG_FACTORY_GET_CLASS (object)->factories,
+                       key);
+
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
 gimp_dialog_factory_finalize (GObject *object)
 {
-  GimpDialogFactory *factory;
+  GimpDialogFactory *factory = GIMP_DIALOG_FACTORY (object);
   GList             *list;
 
-  factory = GIMP_DIALOG_FACTORY (object);
-
-  g_hash_table_remove (GIMP_DIALOG_FACTORY_GET_CLASS (object)->factories,
-                       GIMP_OBJECT (factory)->name);
-
   for (list = factory->registered_dialogs; list; list = g_list_next (list))
     {
-      GimpDialogFactoryEntry *entry;
-
-      entry = (GimpDialogFactoryEntry *) list->data;
+      GimpDialogFactoryEntry *entry = list->data;
 
       g_free (entry->identifier);
       g_free (entry->name);
       g_free (entry->blurb);
       g_free (entry->stock_id);
       g_free (entry->help_id);
-      g_free (entry);
+
+      g_slice_free (GimpDialogFactoryEntry, entry);
     }
 
   if (factory->registered_dialogs)
@@ -225,11 +204,6 @@ gimp_dialog_factory_finalize (GObject *object)
       g_list_free (factory->registered_dialogs);
       factory->registered_dialogs = NULL;
     }
-  if (factory->open_dialogs)
-    {
-      g_list_free (factory->open_dialogs);
-      factory->open_dialogs = NULL;
-    }
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -317,7 +291,7 @@ gimp_dialog_factory_register_entry (GimpDialogFactory *factory,
                                     const gchar       *stock_id,
                                     const gchar       *help_id,
                                     GimpDialogNewFunc  new_func,
-                                    gint               preview_size,
+                                    gint               view_size,
                                     gboolean           singleton,
                                     gboolean           session_managed,
                                     gboolean           remember_size,
@@ -328,7 +302,7 @@ gimp_dialog_factory_register_entry (GimpDialogFactory *factory,
   g_return_if_fail (GIMP_IS_DIALOG_FACTORY (factory));
   g_return_if_fail (identifier != NULL);
 
-  entry = g_new0 (GimpDialogFactoryEntry, 1);
+  entry = g_slice_new0 (GimpDialogFactoryEntry);
 
   entry->identifier       = g_strdup (identifier);
   entry->name             = g_strdup (name);
@@ -336,7 +310,7 @@ gimp_dialog_factory_register_entry (GimpDialogFactory *factory,
   entry->stock_id         = g_strdup (stock_id);
   entry->help_id          = g_strdup (help_id);
   entry->new_func         = new_func;
-  entry->preview_size     = preview_size;
+  entry->view_size        = view_size;
   entry->singleton        = singleton ? TRUE : FALSE;
   entry->session_managed  = session_managed ? TRUE : FALSE;
   entry->remember_size    = remember_size ? TRUE : FALSE;
@@ -396,7 +370,7 @@ gimp_dialog_factory_dialog_new_internal (GimpDialogFactory *factory,
                                          GdkScreen         *screen,
                                          GimpContext       *context,
                                          const gchar       *identifier,
-                                         gint               preview_size,
+                                         gint               view_size,
                                          gboolean           return_existing,
                                          gboolean           present)
 {
@@ -462,21 +436,21 @@ gimp_dialog_factory_dialog_new_internal (GimpDialogFactory *factory,
        *  - the factory's context, which happens when raising a toplevel
        *    dialog was the original request.
        */
-      if (preview_size < GIMP_VIEW_SIZE_TINY)
-        preview_size = entry->preview_size;
+      if (view_size < GIMP_VIEW_SIZE_TINY)
+        view_size = entry->view_size;
 
       if (context)
         dialog = factory->constructor (factory, entry,
                                        context,
-                                       preview_size);
+                                       view_size);
       else if (dock)
         dialog = factory->constructor (factory, entry,
                                        GIMP_DOCK (dock)->context,
-                                       preview_size);
+                                       view_size);
       else
         dialog = factory->constructor (factory, entry,
                                        factory->context,
-                                       preview_size);
+                                       view_size);
 
       if (dialog)
         {
@@ -523,44 +497,42 @@ gimp_dialog_factory_dialog_new_internal (GimpDialogFactory *factory,
         gimp_dialog_factory_add_dialog (factory, dialog);
     }
 
-  /*  finally, if we found an existing dialog or created a new one,
-   *  raise it
+  /*  Finally, if we found an existing dialog or created a new one, raise it.
    */
-  if (dialog)
+  if (! dialog)
+    return NULL;
+
+  if (GTK_WIDGET_TOPLEVEL (dialog))
     {
-      if (GTK_WIDGET_TOPLEVEL (dialog))
+      gtk_window_set_screen (GTK_WINDOW (dialog), screen);
+
+      if (present)
+        gtk_window_present (GTK_WINDOW (dialog));
+    }
+  else if (GIMP_IS_DOCKABLE (dialog))
+    {
+      GimpDockable *dockable = GIMP_DOCKABLE (dialog);
+
+      if (dockable->dockbook && dockable->dockbook->dock)
         {
-          gtk_window_set_screen (GTK_WINDOW (dialog), screen);
+          GtkNotebook *notebook = GTK_NOTEBOOK (dockable->dockbook);
+          gint         num      = gtk_notebook_page_num (notebook, dialog);
 
-          if (present)
-            gtk_window_present (GTK_WINDOW (dialog));
-        }
-      else if (GIMP_IS_DOCKABLE (dialog))
-        {
-          GimpDockable *dockable;
-          gint          page_num;
-
-          dockable = GIMP_DOCKABLE (dialog);
-
-          if (dockable->dockbook && dockable->dockbook->dock)
+          if (num != -1)
             {
-              page_num =
-                gtk_notebook_page_num (GTK_NOTEBOOK (dockable->dockbook),
-                                       dialog);
+              gtk_notebook_set_current_page (notebook, num);
 
-              if (page_num != -1)
-                {
-                  GtkWidget *toplevel;
-
-                  gtk_notebook_set_current_page (GTK_NOTEBOOK (dockable->dockbook),
-                                                 page_num);
-
-                  toplevel = gtk_widget_get_toplevel (dialog);
-
-                  gtk_window_present (GTK_WINDOW (toplevel));
-                }
+              gimp_dockable_blink (dockable);
             }
         }
+
+      if (present)
+        {
+          GtkWidget *toplevel = gtk_widget_get_toplevel (dialog);
+
+          if (GTK_IS_WINDOW (toplevel))
+            gtk_window_present (GTK_WINDOW (toplevel));
+        }
     }
 
   return dialog;
@@ -572,7 +544,7 @@ gimp_dialog_factory_dialog_new_internal (GimpDialogFactory *factory,
  * @screen:       the #GdkScreen the dialog should appear on
  * @identifier:   the identifier of the dialog as registered with
  *                gimp_dialog_factory_register_entry()
- * @preview_size:
+ * @view_size:
  * @present:      whether gtk_window_present() should be called
  *
  * Creates a new toplevel dialog or a #GimpDockable, depending on whether
@@ -585,7 +557,7 @@ GtkWidget *
 gimp_dialog_factory_dialog_new (GimpDialogFactory *factory,
                                 GdkScreen         *screen,
                                 const gchar       *identifier,
-                                gint               preview_size,
+                                gint               view_size,
                                 gboolean           present)
 {
   g_return_val_if_fail (GIMP_IS_DIALOG_FACTORY (factory), NULL);
@@ -596,7 +568,7 @@ gimp_dialog_factory_dialog_new (GimpDialogFactory *factory,
                                                   screen,
                                                   factory->context,
                                                   identifier,
-                                                  preview_size,
+                                                  view_size,
                                                   FALSE,
                                                   present);
 }
@@ -607,7 +579,7 @@ gimp_dialog_factory_dialog_new (GimpDialogFactory *factory,
  * @screen:       the #GdkScreen the dialog should appear on
  * @identifiers:  a '|' separated list of identifiers of dialogs as
  *                registered with gimp_dialog_factory_register_entry()
- * @preview_size:
+ * @view_size:
  *
  * Raises any of a list of already existing toplevel dialog or
  * #GimpDockable if it was already created by this %facory.
@@ -621,7 +593,7 @@ GtkWidget *
 gimp_dialog_factory_dialog_raise (GimpDialogFactory *factory,
                                   GdkScreen         *screen,
                                   const gchar       *identifiers,
-                                  gint               preview_size)
+                                  gint               view_size)
 {
   GtkWidget *dialog;
 
@@ -650,7 +622,7 @@ gimp_dialog_factory_dialog_raise (GimpDialogFactory *factory,
                                                         screen,
                                                         NULL,
                                                         ids[i] ? ids[i] : ids[0],
-                                                        preview_size,
+                                                        view_size,
                                                         TRUE,
                                                         TRUE);
       g_strfreev (ids);
@@ -661,7 +633,7 @@ gimp_dialog_factory_dialog_raise (GimpDialogFactory *factory,
                                                         screen,
                                                         NULL,
                                                         identifiers,
-                                                        preview_size,
+                                                        view_size,
                                                         TRUE,
                                                         TRUE);
     }
@@ -675,7 +647,7 @@ gimp_dialog_factory_dialog_raise (GimpDialogFactory *factory,
  * @dock:         a #GimpDock crated by this %factory.
  * @identifier:   the identifier of the dialog as registered with
  *                gimp_dialog_factory_register_entry()
- * @preview_size:
+ * @view_size:
  *
  * Creates a new #GimpDockable in the context of the #GimpDock it will be
  * added to.
@@ -691,7 +663,7 @@ GtkWidget *
 gimp_dialog_factory_dockable_new (GimpDialogFactory *factory,
                                   GimpDock          *dock,
                                   const gchar       *identifier,
-                                  gint               preview_size)
+                                  gint               view_size)
 {
   g_return_val_if_fail (GIMP_IS_DIALOG_FACTORY (factory), NULL);
   g_return_val_if_fail (GIMP_IS_DOCK (dock), NULL);
@@ -701,7 +673,7 @@ gimp_dialog_factory_dockable_new (GimpDialogFactory *factory,
                                                   gtk_widget_get_screen (GTK_WIDGET (dock)),
                                                   dock->context,
                                                   identifier,
-                                                  preview_size,
+                                                  view_size,
                                                   FALSE,
                                                   FALSE);
 }
@@ -827,7 +799,7 @@ gimp_dialog_factory_add_dialog (GimpDialogFactory *factory,
 
       if (! list) /*  didn't find a session info  */
         {
-          info = g_new0 (GimpSessionInfo, 1);
+          info = gimp_session_info_new ();
 
           info->widget = dialog;
 
@@ -847,7 +819,7 @@ gimp_dialog_factory_add_dialog (GimpDialogFactory *factory,
                *  position when hidden/shown within this(!) session.
                */
               if (entry->session_managed)
-                g_signal_connect (dialog, "configure_event",
+                g_signal_connect (dialog, "configure-event",
                                   G_CALLBACK (gimp_dialog_factory_set_user_pos),
                                   NULL);
             }
@@ -886,7 +858,7 @@ gimp_dialog_factory_add_dialog (GimpDialogFactory *factory,
 
       if (! list) /*  didn't find a session info  */
         {
-          info = g_new0 (GimpSessionInfo, 1);
+          info = gimp_session_info_new ();
 
           info->widget = dialog;
 
@@ -899,7 +871,7 @@ gimp_dialog_factory_add_dialog (GimpDialogFactory *factory,
            *  dialog needs GDK_HINT_USER_POS so it keeps its
            *  position when hidden/shown within this(!) session.
            */
-          g_signal_connect (dialog, "configure_event",
+          g_signal_connect (dialog, "configure-event",
                             G_CALLBACK (gimp_dialog_factory_set_user_pos),
                             NULL);
 
@@ -915,7 +887,7 @@ gimp_dialog_factory_add_dialog (GimpDialogFactory *factory,
                            G_CONNECT_SWAPPED);
 
   if (entry && entry->session_managed && toplevel)
-    g_signal_connect_object (dialog, "configure_event",
+    g_signal_connect_object (dialog, "configure-event",
                              G_CALLBACK (gimp_dialog_factory_dialog_configure),
                              factory,
                              0);
@@ -1023,7 +995,7 @@ gimp_dialog_factory_remove_dialog (GimpDialogFactory *factory,
               factory->session_infos = g_list_remove (factory->session_infos,
                                                       session_info);
 
-              g_free (session_info);
+              gimp_session_info_free (session_info);
             }
 
           break;
@@ -1031,6 +1003,39 @@ gimp_dialog_factory_remove_dialog (GimpDialogFactory *factory,
     }
 }
 
+void
+gimp_dialog_factory_show_toolbox (GimpDialogFactory *toolbox_factory)
+{
+  GtkWidget *toolbox;
+
+  g_return_if_fail (GIMP_IS_DIALOG_FACTORY (toolbox_factory));
+
+  toolbox = gimp_dialog_factory_get_toolbox (toolbox_factory);
+
+  if (toolbox)
+    gtk_window_present (GTK_WINDOW (toolbox));
+}
+
+void
+gimp_dialog_factory_hide_dialog (GtkWidget *dialog)
+{
+  g_return_if_fail (GTK_IS_WIDGET (dialog));
+  g_return_if_fail (GTK_WIDGET_TOPLEVEL (dialog));
+
+  if (! gimp_dialog_factory_from_widget (dialog, NULL))
+    {
+      g_warning ("%s: dialog was not created by a GimpDialogFactory",
+                 G_STRFUNC);
+      return;
+    }
+
+  gtk_widget_hide (dialog);
+
+  if (! dialogs_shown)
+    g_object_set_data (G_OBJECT (dialog), GIMP_DIALOG_VISIBILITY_KEY,
+                       GINT_TO_POINTER (GIMP_DIALOG_VISIBILITY_INVISIBLE));
+}
+
 void
 gimp_dialog_factories_session_save (GimpConfigWriter *writer)
 {
@@ -1070,63 +1075,26 @@ gimp_dialog_factories_session_clear (void)
 }
 
 void
-gimp_dialog_factories_toggle (GimpDialogFactory *toolbox_factory,
-                              gboolean           ensure_visibility)
+gimp_dialog_factories_toggle (void)
 {
-  static GimpDialogShowState toggle_state = GIMP_DIALOG_SHOW_ALL;
-  static gboolean            doing_update = FALSE;
-
   GimpDialogFactoryClass *factory_class;
 
-  if (doing_update)
-    return;
-
-  if (ensure_visibility && toggle_state != GIMP_DIALOG_HIDE_ALL)
-    {
-      GList *list;
-
-      for (list = toolbox_factory->open_dialogs; list; list = list->next)
-        {
-          if (GTK_IS_WIDGET (list->data) && GTK_WIDGET_TOPLEVEL (list->data))
-            gtk_window_present (GTK_WINDOW (list->data));
-        }
-
-      return;
-    }
-
-  doing_update = TRUE;
-
   factory_class = g_type_class_peek (GIMP_TYPE_DIALOG_FACTORY);
 
-  switch (toggle_state)
+  if (dialogs_shown)
     {
-    case GIMP_DIALOG_SHOW_ALL:
-      toggle_state = GIMP_DIALOG_HIDE_ALL;
-
+      dialogs_shown = FALSE;
       g_hash_table_foreach (factory_class->factories,
                             (GHFunc) gimp_dialog_factories_hide_foreach,
                             NULL);
-      break;
-
-    case GIMP_DIALOG_HIDE_ALL:
-      toggle_state = GIMP_DIALOG_SHOW_TOOLBOX;
-
-      gimp_dialog_factories_show_foreach (GIMP_OBJECT (toolbox_factory)->name,
-                                          toolbox_factory,
-                                          NULL);
-      break;
-
-    case GIMP_DIALOG_SHOW_TOOLBOX:
-      toggle_state = GIMP_DIALOG_SHOW_ALL;
-
+    }
+  else
+    {
+      dialogs_shown = TRUE;
       g_hash_table_foreach (factory_class->factories,
                             (GHFunc) gimp_dialog_factories_show_foreach,
                             NULL);
-    default:
-      break;
     }
-
-  doing_update = FALSE;
 }
 
 void
@@ -1136,9 +1104,10 @@ gimp_dialog_factories_set_busy (void)
 
   factory_class = g_type_class_peek (GIMP_TYPE_DIALOG_FACTORY);
 
-  g_hash_table_foreach (factory_class->factories,
-                        (GHFunc) gimp_dialog_factories_set_busy_foreach,
-                        NULL);
+  if (factory_class)
+    g_hash_table_foreach (factory_class->factories,
+                          (GHFunc) gimp_dialog_factories_set_busy_foreach,
+                          NULL);
 }
 
 void
@@ -1148,9 +1117,10 @@ gimp_dialog_factories_unset_busy (void)
 
   factory_class = g_type_class_peek (GIMP_TYPE_DIALOG_FACTORY);
 
-  g_hash_table_foreach (factory_class->factories,
-                        (GHFunc) gimp_dialog_factories_unset_busy_foreach,
-                        NULL);
+  if (factory_class)
+    g_hash_table_foreach (factory_class->factories,
+                          (GHFunc) gimp_dialog_factories_unset_busy_foreach,
+                          NULL);
 }
 
 
@@ -1186,9 +1156,9 @@ static GtkWidget *
 gimp_dialog_factory_default_constructor (GimpDialogFactory      *factory,
                                          GimpDialogFactoryEntry *entry,
                                          GimpContext            *context,
-                                         gint                    preview_size)
+                                         gint                    view_size)
 {
-  return entry->new_func (factory, context, preview_size);
+  return entry->new_func (factory, context, view_size);
 }
 
 static void
@@ -1308,7 +1278,7 @@ gimp_dialog_factories_save_foreach (gconstpointer      key,
           (info->toplevel_entry && ! info->toplevel_entry->session_managed))
         continue;
 
-      gimp_session_info_save (info, GIMP_OBJECT (factory)->name, writer);
+      gimp_session_info_serialize (writer, info, GIMP_OBJECT (factory)->name);
     }
 }
 
@@ -1401,7 +1371,19 @@ gimp_dialog_factories_show_foreach (gconstpointer      key,
           if (! GTK_WIDGET_VISIBLE (list->data) &&
               visibility == GIMP_DIALOG_VISIBILITY_VISIBLE)
             {
-              gtk_widget_show (GTK_WIDGET (list->data));
+              GtkWindow *window       = GTK_WINDOW (list->data);
+              gboolean   focus_on_map = gtk_window_get_focus_on_map (window);
+
+              if (focus_on_map)
+                gtk_window_set_focus_on_map (window, FALSE);
+
+              gtk_widget_show (GTK_WIDGET (window));
+
+              if (GTK_WIDGET_VISIBLE (window))
+                gdk_window_raise (GTK_WIDGET (window)->window);
+
+              if (focus_on_map)
+                gtk_window_set_focus_on_map (window, TRUE);
             }
         }
     }
@@ -1463,3 +1445,18 @@ gimp_dialog_factories_unset_busy_foreach (gconstpointer      key,
         }
     }
 }
+
+/*  The only toplevel widget in the toolbox factory is the toolbox  */
+static GtkWidget *
+gimp_dialog_factory_get_toolbox (GimpDialogFactory *toolbox_factory)
+{
+  GList *list;
+
+  for (list = toolbox_factory->open_dialogs; list; list = list->next)
+    {
+      if (GTK_IS_WIDGET (list->data) && GTK_WIDGET_TOPLEVEL (list->data))
+        return list->data;
+    }
+
+  return NULL;
+}
