@@ -27,24 +27,22 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
-#include <stdio.h>
-#include <stdlib.h>
+#define _GNU_SOURCE  /* need PATH_MAX */
+
 #include <string.h>
-#include <time.h>
+#include <limits.h>
 
-#include <gtk/gtk.h>
+#include <glib/gstdio.h>
 
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
 #include "libgimp/stdplugins-intl.h"
 
-#ifndef PATH_MAX
-#define PATH_MAX _MAX_PATH
+#if ! defined PATH_MAX && defined _MAX_PATH
+#  define PATH_MAX _MAX_PATH
 #endif
 
 /** qbist renderer ***********************************************************/
@@ -53,9 +51,9 @@
 #define NUM_REGISTERS    6
 #define PREVIEW_SIZE    64
 
-#define PLUG_IN_NAME    "plug_in_qbist"
+#define PLUG_IN_PROC    "plug-in-qbist"
+#define PLUG_IN_BINARY  "gqbist"
 #define PLUG_IN_VERSION "January 2001, 1.12"
-#define HELP_ID         "plug-in-qbist"
 
 /** types *******************************************************************/
 
@@ -113,7 +111,9 @@ static void      dialog_update_previews (GtkWidget *widget,
 static void      dialog_select_preview  (GtkWidget *widget,
                                          ExpInfo   *n_info);
 
-static QbistInfo qbist_info;
+static QbistInfo  qbist_info;
+static GRand     *gr = NULL;
+
 
 /** qbist functions *********************************************************/
 
@@ -121,9 +121,6 @@ static void
 create_info (ExpInfo *info)
 {
   gint k;
-  GRand *gr;
-
-  gr = g_rand_new();
 
   for (k = 0; k < MAX_TRANSFORMS; k++)
     {
@@ -132,8 +129,6 @@ create_info (ExpInfo *info)
       info->control[k] = g_rand_int_range (gr, 0, NUM_REGISTERS);
       info->dest[k] = g_rand_int_range (gr, 0, NUM_REGISTERS);
     }
-
-  g_rand_free(gr);
 }
 
 static void
@@ -141,9 +136,7 @@ modify_info (ExpInfo *o_info,
              ExpInfo *n_info)
 {
   gint k, n;
-  GRand *gr;
 
-  gr = g_rand_new ();
   *n_info = *o_info;
   n = g_rand_int_range (gr, 0, MAX_TRANSFORMS);
   for (k = 0; k < n; k++)
@@ -171,7 +164,6 @@ modify_info (ExpInfo *o_info,
           break;
         }
     }
-  g_rand_free (gr);
 }
 
 /*
@@ -386,7 +378,7 @@ qbist (ExpInfo *info,
 
 /** Plugin interface *********************************************************/
 
-GimpPlugInInfo PLUG_IN_INFO =
+const GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,                         /* init_proc  */
   NULL,                         /* quit_proc  */
@@ -401,14 +393,17 @@ query (void)
 {
   GimpParamDef args[] =
   {
-    { GIMP_PDB_INT32,    "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_INT32,    "run-mode", "Interactive, non-interactive" },
     { GIMP_PDB_IMAGE,    "image",    "Input image (unused)"         },
     { GIMP_PDB_DRAWABLE, "drawable", "Input drawable"               }
   };
 
-  gimp_install_procedure (PLUG_IN_NAME,
-                          "Create images based on a random genetic formula",
-                          "This Plug-in is based on an article by Jörn Loviscach (appeared in c't 10/95, page 326). It generates modern art pictures from a random genetic formula.",
+  gimp_install_procedure (PLUG_IN_PROC,
+                          N_("Generate a huge variety of abstract patterns"),
+                          "This Plug-in is based on an article by "
+                          "Jörn Loviscach (appeared in c't 10/95, page 326). "
+                          "It generates modern art pictures from a random "
+                          "genetic formula.",
                           "Jörn Loviscach, Jens Ch. Restemeier",
                           "Jörn Loviscach, Jens Ch. Restemeier",
                           PLUG_IN_VERSION,
@@ -418,7 +413,7 @@ query (void)
                           G_N_ELEMENTS (args), 0,
                           args, NULL);
 
-  gimp_plugin_menu_register (PLUG_IN_NAME, "<Image>/Filters/Render/Pattern");
+  gimp_plugin_menu_register (PLUG_IN_PROC, "<Image>/Filters/Render/Pattern");
 }
 
 static void
@@ -437,7 +432,7 @@ run (const gchar      *name,
   GimpPDBStatusType  status;
 
   *nreturn_vals = 1;
-  *return_vals = values;
+  *return_vals  = values;
 
   status = GIMP_PDB_SUCCESS;
 
@@ -464,6 +459,8 @@ run (const gchar      *name,
 
   if (status == GIMP_PDB_SUCCESS)
     {
+      gr = g_rand_new ();
+
       memset (&qbist_info, 0, sizeof (qbist_info));
       create_info (&qbist_info.info);
       qbist_info.oversampling = 4;
@@ -472,13 +469,13 @@ run (const gchar      *name,
         {
         case GIMP_RUN_INTERACTIVE:
           /* Possibly retrieve data */
-          gimp_get_data (PLUG_IN_NAME, &qbist_info);
+          gimp_get_data (PLUG_IN_PROC, &qbist_info);
 
           /* Get information from the dialog */
           if (dialog_run ())
             {
               status = GIMP_PDB_SUCCESS;
-              gimp_set_data (PLUG_IN_NAME, &qbist_info, sizeof (QbistInfo));
+              gimp_set_data (PLUG_IN_PROC, &qbist_info, sizeof (QbistInfo));
             }
           else
             status = GIMP_PDB_EXECUTION_ERROR;
@@ -490,7 +487,7 @@ run (const gchar      *name,
 
         case GIMP_RUN_WITH_LAST_VALS:
           /* Possibly retrieve data */
-          gimp_get_data (PLUG_IN_NAME, &qbist_info);
+          gimp_get_data (PLUG_IN_PROC, &qbist_info);
           status = GIMP_PDB_SUCCESS;
           break;
 
@@ -511,7 +508,7 @@ run (const gchar      *name,
 
           optimize (&qbist_info.info);
 
-          gimp_progress_init (_("Qbist ..."));
+          gimp_progress_init (_("Qbist"));
 
           for (pr = gimp_pixel_rgns_register (1, &imagePR);
                pr != NULL;
@@ -544,6 +541,8 @@ run (const gchar      *name,
 
           gimp_displays_flush ();
         }
+
+      g_rand_free (gr);
     }
 
   values[0].type          = GIMP_PDB_STATUS;
@@ -555,7 +554,8 @@ run (const gchar      *name,
 /** User interface ***********************************************************/
 
 static GtkWidget *preview[9];
-static ExpInfo   info[9];
+static ExpInfo    info[9];
+static ExpInfo    last_info[9];
 
 static void
 dialog_new_variations (GtkWidget *widget,
@@ -594,6 +594,7 @@ static void
 dialog_select_preview (GtkWidget *widget,
                        ExpInfo   *n_info)
 {
+  memcpy (last_info, info, sizeof (info));
   info[0] = *n_info;
   dialog_new_variations (widget, NULL);
   dialog_update_previews (widget, NULL);
@@ -622,7 +623,7 @@ load_data (gchar *name)
   FILE   *f;
   guint8  buf[288];
 
-  f = fopen (name, "rb");
+  f = g_fopen (name, "rb");
   if (f == NULL)
     {
       return FALSE;
@@ -657,7 +658,7 @@ save_data (gchar *name)
   FILE   *f;
   guint8  buf[288];
 
-  f = fopen (name, "wb");
+  f = g_fopen (name, "wb");
   if (f == NULL)
     {
       return FALSE;
@@ -682,6 +683,17 @@ save_data (gchar *name)
   return TRUE;
 }
 
+static void
+dialog_undo (GtkWidget *widget,
+             gpointer   data)
+{
+  ExpInfo temp_info[9];
+
+  memcpy (temp_info, info, sizeof (info));
+  memcpy (info, last_info, sizeof (info));
+  dialog_update_previews (NULL, NULL);
+  memcpy (last_info, temp_info, sizeof (info));
+}
 
 static void
 dialog_load (GtkWidget *widget,
@@ -692,7 +704,7 @@ dialog_load (GtkWidget *widget,
 
   parent = gtk_widget_get_toplevel (widget);
 
-  dialog = gtk_file_chooser_dialog_new (_("Load QBE file"),
+  dialog = gtk_file_chooser_dialog_new (_("Load QBE File"),
                                         GTK_WINDOW (parent),
                                         GTK_FILE_CHOOSER_ACTION_OPEN,
 
@@ -701,6 +713,10 @@ dialog_load (GtkWidget *widget,
 
                                         NULL);
 
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
   gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), qbist_info.path);
@@ -709,7 +725,7 @@ dialog_load (GtkWidget *widget,
     {
       gchar *name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
-      strcpy (qbist_info.path, name);
+      strncpy (qbist_info.path, name, PATH_MAX - 1);
       load_data (qbist_info.path);
 
       g_free (name);
@@ -730,7 +746,7 @@ dialog_save (GtkWidget *widget,
 
   parent = gtk_widget_get_toplevel (widget);
 
-  dialog = gtk_file_chooser_dialog_new (_("Save (middle transform) as QBE file"),
+  dialog = gtk_file_chooser_dialog_new (_("Save as QBE File"),
                                         GTK_WINDOW (parent),
                                         GTK_FILE_CHOOSER_ACTION_SAVE,
 
@@ -739,22 +755,28 @@ dialog_save (GtkWidget *widget,
 
                                         NULL);
 
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
+  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog),
+                                                  TRUE);
+
   gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), qbist_info.path);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
     {
       gchar *name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
-      strcpy (qbist_info.path, name);
+      strncpy (qbist_info.path, name, PATH_MAX - 1);
       save_data (qbist_info.path);
 
       g_free (name);
     }
 
   gtk_widget_destroy (dialog);
-
 }
 
 static void
@@ -776,17 +798,24 @@ dialog_run (void)
   gint       i;
   gboolean   run;
 
-  gimp_ui_init ("gqbist", TRUE);
+  gimp_ui_init (PLUG_IN_BINARY, TRUE);
 
-  dialog = gimp_dialog_new (_("G-Qbist"), "gqbist",
+  dialog = gimp_dialog_new (_("G-Qbist"), PLUG_IN_BINARY,
                             NULL, 0,
-                            gimp_standard_help_func, HELP_ID,
+                            gimp_standard_help_func, PLUG_IN_PROC,
 
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK,     GTK_RESPONSE_OK,
 
                             NULL);
 
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
+
+  gimp_window_set_transient (GTK_WINDOW (dialog));
+
   vbox = gtk_vbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
@@ -801,6 +830,7 @@ dialog_run (void)
 
   info[0] = qbist_info.info;
   dialog_new_variations (NULL, NULL);
+  memcpy (last_info, info, sizeof (info));
 
   for (i = 0; i < 9; i++)
     {
@@ -831,11 +861,19 @@ dialog_run (void)
                     NULL);
 
   bbox = gtk_hbutton_box_new ();
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
   gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
   gtk_widget_show (bbox);
 
+  button = gtk_button_new_from_stock (GTK_STOCK_UNDO);
+  gtk_container_add (GTK_CONTAINER (bbox), button);
+  gtk_widget_show (button);
+
+  g_signal_connect (button, "clicked",
+                    G_CALLBACK (dialog_undo),
+                    NULL);
+
   button = gtk_button_new_from_stock (GTK_STOCK_OPEN);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_container_add (GTK_CONTAINER (bbox), button);
   gtk_widget_show (button);
 
@@ -844,7 +882,6 @@ dialog_run (void)
                     NULL);
 
   button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_container_add (GTK_CONTAINER (bbox), button);
   gtk_widget_show (button);
 
