@@ -1,4 +1,4 @@
-/* The GIMP -- an image manipulation program
+/* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* Neon filter for the GIMP for BIPS
+/* Neon filter for GIMP for BIPS
  *  -Spencer Kimball
  *
  * This filter works in a manner similar to the "edge"
@@ -37,6 +37,10 @@
 #include "libgimp/stdplugins-intl.h"
 
 
+#define PLUG_IN_PROC   "plug-in-neon"
+#define PLUG_IN_BINARY "neon"
+
+
 typedef struct
 {
   gdouble radius;
@@ -87,7 +91,7 @@ static void      combine_to_gradient (guchar  *dest,
 
 /***** Local vars *****/
 
-GimpPlugInInfo PLUG_IN_INFO =
+const GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init  */
   NULL,  /* quit  */
@@ -109,12 +113,12 @@ MAIN ()
 static void
 query (void)
 {
-  static GimpParamDef args[] =
+  static const GimpParamDef args[] =
   {
-    { GIMP_PDB_INT32,    "run_mode", "Interactive, non-interactive" },
-    { GIMP_PDB_IMAGE,    "image",    "Input image (unused)" },
-    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
-    { GIMP_PDB_FLOAT,    "radius",   "Radius of neon effect (in pixels)" },
+    { GIMP_PDB_INT32,    "run-mode", "Interactive, non-interactive"          },
+    { GIMP_PDB_IMAGE,    "image",    "Input image (unused)"                  },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable"                        },
+    { GIMP_PDB_FLOAT,    "radius",   "Radius of neon effect (in pixels)"     },
     { GIMP_PDB_FLOAT,    "amount",   "Effect enhancement variable (0.0 - 1.0)" },
   };
 
@@ -126,8 +130,8 @@ query (void)
     "the processing time constant between large and small"
     "standard deviations.";
 
-  gimp_install_procedure ("plug_in_neon",
-                          "Resolution independent edge detection",
+  gimp_install_procedure (PLUG_IN_PROC,
+                          N_("Simulate the glowing boundary of a neon light"),
                           help_string,
                           "Spencer Kimball",
                           "Bit Specialists, Inc.",
@@ -138,7 +142,7 @@ query (void)
                           G_N_ELEMENTS (args), 0,
                           args, NULL);
 
-  gimp_plugin_menu_register ("plug_in_neon", "<Image>/Filters/Edge-Detect");
+  gimp_plugin_menu_register (PLUG_IN_PROC, "<Image>/Filters/Edge-Detect");
 }
 
 static void
@@ -173,7 +177,7 @@ run (const gchar      *name,
     {
     case GIMP_RUN_INTERACTIVE:
       /*  Possibly retrieve data  */
-      gimp_get_data ("plug_in_neon", &evals);
+      gimp_get_data (PLUG_IN_PROC, &evals);
 
       /*  First acquire information with a dialog  */
       if (! neon_dialog (drawable))
@@ -193,7 +197,7 @@ run (const gchar      *name,
 
     case GIMP_RUN_WITH_LAST_VALS:
       /*  Possibly retrieve data  */
-      gimp_get_data ("plug_in_neon", &evals);
+      gimp_get_data (PLUG_IN_PROC, &evals);
       break;
 
     default:
@@ -204,7 +208,7 @@ run (const gchar      *name,
   if (gimp_drawable_is_rgb (drawable->drawable_id) ||
       gimp_drawable_is_gray (drawable->drawable_id))
     {
-      gimp_progress_init (_("Neon..."));
+      gimp_progress_init (_("Neon"));
 
       /*  run the neon effect  */
       neon (drawable, evals.radius, evals.amount, NULL);
@@ -214,7 +218,7 @@ run (const gchar      *name,
 
       /*  Store data  */
       if (run_mode == GIMP_RUN_INTERACTIVE)
-        gimp_set_data ("plug_in_neon", &evals, sizeof (NeonVals));
+        gimp_set_data (PLUG_IN_PROC, &evals, sizeof (NeonVals));
     }
   else
     {
@@ -381,7 +385,8 @@ neon (GimpDrawable *drawable,
           gimp_pixel_rgn_set_col (&dest_rgn, dest, col + x1, y1, (y2 - y1));
 
           progress += height * radius;
-          if ((col % 5) == 0)
+
+          if ((col % 20) == 0)
             gimp_progress_update ((double) progress / (double) max_progress);
         }
     }
@@ -470,7 +475,7 @@ neon (GimpDrawable *drawable,
           gimp_pixel_rgn_set_row (&dest_rgn, dest, x1, row + y1, (x2 - x1));
 
           progress += width * radius;
-          if ((row % 5) == 0)
+          if ((row % 20) == 0)
             gimp_progress_update ((double) progress / (double) max_progress);
         }
     }
@@ -647,15 +652,6 @@ find_constants (gdouble n_p[],
     gdouble sum_n_p, sum_n_m, sum_d;
     gdouble a, b;
 
-    /*
-    for (i = 0; i <=4; i++)
-      {
-        fprintf (stderr, "n_p[%d] = %f\n", i, n_p[i]);
-        fprintf (stderr, "n_m[%d] = %f\n", i, n_m[i]);
-        fprintf (stderr, "d_p[%d] = %f\n", i, d_p[i]);
-      }
-    */
-
     sum_n_p = 0.0;
     sum_n_m = 0.0;
     sum_d   = 0.0;
@@ -692,17 +688,24 @@ neon_dialog (GimpDrawable *drawable)
   GtkObject *scale_data;
   gboolean   run;
 
-  gimp_ui_init ("neon", FALSE);
+  gimp_ui_init (PLUG_IN_BINARY, FALSE);
 
-  dialog = gimp_dialog_new (_("Neon Detection"), "neon",
+  dialog = gimp_dialog_new (_("Neon Detection"), PLUG_IN_BINARY,
                             NULL, 0,
-                            gimp_standard_help_func, "plug-in-neon",
+                            gimp_standard_help_func, PLUG_IN_PROC,
 
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK,     GTK_RESPONSE_OK,
 
                             NULL);
 
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
+
+  gimp_window_set_transient (GTK_WINDOW (dialog));
+
   main_vbox = gtk_vbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), main_vbox);
@@ -730,10 +733,10 @@ neon_dialog (GimpDrawable *drawable)
                                      8 * MAX (drawable->width, drawable->height),
                                      NULL, NULL);
 
-  g_signal_connect (scale_data, "value_changed",
+  g_signal_connect (scale_data, "value-changed",
                     G_CALLBACK (gimp_double_adjustment_update),
                     &evals.radius);
-  g_signal_connect_swapped (scale_data, "value_changed",
+  g_signal_connect_swapped (scale_data, "value-changed",
                             G_CALLBACK (gimp_preview_invalidate),
                             preview);
 
@@ -744,10 +747,10 @@ neon_dialog (GimpDrawable *drawable)
                                      TRUE, 0, 0,
                                      NULL, NULL);
 
-  g_signal_connect (scale_data, "value_changed",
+  g_signal_connect (scale_data, "value-changed",
                     G_CALLBACK (gimp_double_adjustment_update),
                     &evals.amount);
-  g_signal_connect_swapped (scale_data, "value_changed",
+  g_signal_connect_swapped (scale_data, "value-changed",
                             G_CALLBACK (gimp_preview_invalidate),
                             preview);
 
