@@ -1,4 +1,4 @@
-/* The GIMP -- an image manipulation program
+/* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,29 +16,27 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* WMF loading file filter for the GIMP
+/* WMF loading file filter for GIMP
  * -Dom Lachowicz <cinamod@hotmail.com> 2003
  * -Francis James Franklin <fjf@alinameridon.com>
  */
 
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <libwmf/api.h>
 #include <libwmf/gd.h>
 
-#include <gtk/gtk.h>
-
-#include <libgimpmath/gimpmath.h>
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
+#include <libgimpmath/gimpmath.h>
 
 #include "libgimp/stdplugins-intl.h"
 
 
+#define LOAD_PROC               "file-wmf-load"
+#define LOAD_THUMB_PROC         "file-wmf-load-thumb"
+#define PLUG_IN_BINARY          "wmf"
+
 #define WMF_DEFAULT_RESOLUTION	90.0
 #define WMF_DEFAULT_SIZE        500
 #define WMF_PREVIEW_SIZE        128
@@ -72,10 +70,10 @@ static guchar   *wmf_get_pixbuf (const gchar       *filename,
                                  gint              *width,
                                  gint              *height);
 static guchar   *wmf_load_file  (const gchar       *filename,
-                                 gint              *width,
-                                 gint              *height);
+                                 guint             *width,
+                                 guint             *height);
 
-GimpPlugInInfo PLUG_IN_INFO =
+const GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,   /* init_proc  */
   NULL,   /* quit_proc  */
@@ -92,37 +90,34 @@ MAIN ()
 static void
 query (void)
 {
-  static GimpParamDef load_args[] =
-    {
-      { GIMP_PDB_INT32,  "run_mode",     "Interactive, non-interactive" },
-      { GIMP_PDB_STRING, "filename",     "The name of the file to load" },
-      { GIMP_PDB_STRING, "raw_filename", "The name of the file to load" },
-      { GIMP_PDB_FLOAT,  "resolution",
-      "Resolution to use for rendering the WMF (defaults to 72 dpi"     },
-      { GIMP_PDB_INT32,  "width",
-      "Width (in pixels) to load the WMF in, 0 for original width"      },
-      { GIMP_PDB_INT32,  "height",
-      "Height (in pixels) to load the WMF in, 0 for original height"    }
-    };
+  static const GimpParamDef load_args[] =
+  {
+    { GIMP_PDB_INT32,  "run-mode",     "Interactive, non-interactive" },
+    { GIMP_PDB_STRING, "filename",     "The name of the file to load" },
+    { GIMP_PDB_STRING, "raw-filename", "The name of the file to load" },
+    { GIMP_PDB_FLOAT,  "resolution",   "Resolution to use for rendering the WMF (defaults to 72 dpi"     },
+    { GIMP_PDB_INT32,  "width",        "Width (in pixels) to load the WMF in, 0 for original width"      },
+    { GIMP_PDB_INT32,  "height",       "Height (in pixels) to load the WMF in, 0 for original height"    }
+  };
 
-  static GimpParamDef load_return_vals[] =
-    {
-      { GIMP_PDB_IMAGE,   "image",         "Output image"               }
-    };
+  static const GimpParamDef load_return_vals[] =
+  {
+    { GIMP_PDB_IMAGE,   "image",         "Output image"               }
+  };
 
-  static GimpParamDef thumb_args[] =
+  static const GimpParamDef thumb_args[] =
   {
     { GIMP_PDB_STRING, "filename",     "The name of the file to load"   },
-    { GIMP_PDB_INT32,  "thumb_size",   "Preferred thumbnail size"       }
+    { GIMP_PDB_INT32,  "thumb-size",   "Preferred thumbnail size"       }
   };
-  static GimpParamDef thumb_return_vals[] =
+  static const GimpParamDef thumb_return_vals[] =
   {
     { GIMP_PDB_IMAGE,  "image",        "Thumbnail image"                },
-    { GIMP_PDB_INT32,  "image_width",  "Width of full-sized image"      },
-    { GIMP_PDB_INT32,  "image_height", "Height of full-sized image"     }
+    { GIMP_PDB_INT32,  "image-width",  "Width of full-sized image"      },
+    { GIMP_PDB_INT32,  "image-height", "Height of full-sized image"     }
   };
 
-  gimp_install_procedure ("file_wmf_load",
+  gimp_install_procedure (LOAD_PROC,
                           "Loads files in the WMF file format",
                           "Loads files in the WMF file format",
                           "Dom Lachowicz <cinamod@hotmail.com>",
@@ -135,12 +130,12 @@ query (void)
                           G_N_ELEMENTS (load_return_vals),
                           load_args, load_return_vals);
 
-  gimp_register_file_handler_mime ("file_wmf_load", "image/x-wmf");
-  gimp_register_magic_load_handler ("file_wmf_load",
+  gimp_register_file_handler_mime (LOAD_PROC, "image/x-wmf");
+  gimp_register_magic_load_handler (LOAD_PROC,
                                     "wmf,apm", "",
                                     "0,string,\\327\\315\\306\\232,0,string,\\1\\0\\11\\0");
 
-  gimp_install_procedure ("file_wmf_load_thumb",
+  gimp_install_procedure (LOAD_THUMB_PROC,
                           "Loads a small preview from a WMF image",
                           "",
                           "Dom Lachowicz <cinamod@hotmail.com>",
@@ -152,7 +147,8 @@ query (void)
                           G_N_ELEMENTS (thumb_args),
                           G_N_ELEMENTS (thumb_return_vals),
                           thumb_args, thumb_return_vals);
-  gimp_register_thumbnail_loader ("file_wmf_load", "file_wmf_load_thumb");
+
+  gimp_register_thumbnail_loader (LOAD_PROC, LOAD_THUMB_PROC);
 }
 
 /*
@@ -183,11 +179,11 @@ run (const gchar      *name,
   values[0].type          = GIMP_PDB_STATUS;
   values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
 
-  if (strcmp (name, "file_wmf_load") == 0)
+  if (strcmp (name, LOAD_PROC) == 0)
     {
       filename = param[1].data.d_string;
 
-      gimp_get_data ("file_wmf_load", &load_vals);
+      gimp_get_data (LOAD_PROC, &load_vals);
 
       switch (run_mode)
         {
@@ -206,7 +202,7 @@ run (const gchar      *name,
           break;
         }
     }
-  else if (strcmp (name, "file_wmf_load_thumb") == 0)
+  else if (strcmp (name, LOAD_THUMB_PROC) == 0)
     {
       gint size = param[1].data.d_int32;
 
@@ -265,7 +261,7 @@ run (const gchar      *name,
 
   if (status == GIMP_PDB_SUCCESS)
     {
-      if (strcmp (name, "file_wmf_load_thumb") == 0)
+      if (strcmp (name, LOAD_THUMB_PROC) == 0)
         {
           *nreturn_vals = 4;
           values[2].type         = GIMP_PDB_INT32;
@@ -275,7 +271,7 @@ run (const gchar      *name,
         }
       else
         {
-          gimp_set_data ("file_wmf_load", &load_vals, sizeof (load_vals));
+          gimp_set_data (LOAD_PROC, &load_vals, sizeof (load_vals));
         }
     }
 
@@ -285,11 +281,13 @@ run (const gchar      *name,
 
 static GtkWidget *size_label = NULL;
 
+
 /*  This function retrieves the pixel size from a WMF file. */
 static gboolean
 load_wmf_size (const gchar *filename,
                WmfLoadVals *vals)
 {
+  GMappedFile    *file;
   /* the bits we need to decode the WMF via libwmf2's GD layer  */
   wmf_error_t     err;
   gulong          flags;
@@ -297,11 +295,13 @@ load_wmf_size (const gchar *filename,
   wmfAPI         *API   = NULL;
   wmfAPI_Options  api_options;
   wmfD_Rect       bbox;
-  gint            width;
-  gint            height;
+  guint           width   = -1;
+  guint           height  = -1;
   gboolean        success = TRUE;
 
-  width = height = -1;
+  file = g_mapped_file_new (filename, FALSE, NULL);
+  if (! file)
+    return FALSE;
 
   flags = WMF_OPT_IGNORE_NONFATAL | WMF_OPT_FUNCTION;
   api_options.function = wmf_gd_function;
@@ -313,7 +313,9 @@ load_wmf_size (const gchar *filename,
   ddata = WMF_GD_GetData (API);
   ddata->type = wmf_gd_image;
 
-  err = wmf_file_open (API, filename);
+  err = wmf_mem_open (API,
+                      (guchar *) g_mapped_file_get_contents (file),
+                      g_mapped_file_get_length (file));
   if (err != wmf_E_None)
     success = FALSE;
 
@@ -326,6 +328,9 @@ load_wmf_size (const gchar *filename,
   if (err != wmf_E_None || width <= 0 || height <= 0)
     success = FALSE;
 
+  wmf_mem_close (API);
+  g_mapped_file_free (file);
+
   if (width < 1 || height < 1)
     {
       width  = WMF_DEFAULT_SIZE;
@@ -339,7 +344,7 @@ load_wmf_size (const gchar *filename,
     {
       if (size_label)
         {
-          gchar *text = g_strdup_printf (_("%d x %d"), width, height);
+          gchar *text = g_strdup_printf (_("%d × %d"), width, height);
 
           gtk_label_set_text (GTK_LABEL (size_label), text);
           g_free (text);
@@ -479,19 +484,26 @@ load_dialog (const gchar *filename)
   WmfLoadVals  vals = { WMF_DEFAULT_RESOLUTION,
                         - WMF_PREVIEW_SIZE, - WMF_PREVIEW_SIZE };
 
-  gimp_ui_init ("wmf", FALSE);
+  gimp_ui_init (PLUG_IN_BINARY, FALSE);
 
-  dialog = gimp_dialog_new (_("Render Windows Metafile"), "wmf",
+  dialog = gimp_dialog_new (_("Render Windows Metafile"), PLUG_IN_BINARY,
                             NULL, 0,
-                            gimp_standard_help_func, "wmf",
+                            gimp_standard_help_func, LOAD_PROC,
 
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK,     GTK_RESPONSE_OK,
 
                             NULL);
 
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_OK,
+                                           GTK_RESPONSE_CANCEL,
+                                           -1);
+
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
+  gimp_window_set_transient (GTK_WINDOW (dialog));
+
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
@@ -518,7 +530,7 @@ load_dialog (const gchar *filename)
   gtk_container_add (GTK_CONTAINER (frame), image);
   gtk_widget_show (image);
 
-  g_signal_connect (image, "size_allocate",
+  g_signal_connect (image, "size-allocate",
                     G_CALLBACK (wmf_preview_callback),
                     pixels);
 
@@ -595,7 +607,7 @@ load_dialog (const gchar *filename)
   gimp_size_entry_set_resolution (size, 0, load_vals.resolution, FALSE);
   gimp_size_entry_set_resolution (size, 1, load_vals.resolution, FALSE);
 
-  g_signal_connect (size, "value_changed",
+  g_signal_connect (size, "value-changed",
 		    G_CALLBACK (load_dialog_size_callback),
                     NULL);
 
@@ -621,7 +633,7 @@ load_dialog (const gchar *filename)
   gtk_table_attach_defaults (GTK_TABLE (table2), spinbutton, 0, 1, 0, 1);
   gtk_widget_show (spinbutton);
 
-  g_signal_connect (xadj, "value_changed",
+  g_signal_connect (xadj, "value-changed",
 		    G_CALLBACK (load_dialog_ratio_callback),
 		    NULL);
 
@@ -643,7 +655,7 @@ load_dialog (const gchar *filename)
   gtk_table_attach_defaults (GTK_TABLE (table2), spinbutton, 0, 1, 1, 2);
   gtk_widget_show (spinbutton);
 
-  g_signal_connect (yadj, "value_changed",
+  g_signal_connect (yadj, "value-changed",
 		    G_CALLBACK (load_dialog_ratio_callback),
 		    NULL);
 
@@ -750,6 +762,7 @@ wmf_get_pixbuf (const gchar *filename,
                 gint        *width,
                 gint        *height)
 {
+  GMappedFile    *file;
   guchar         *pixels   = NULL;
 
   /* the bits we need to decode the WMF via libwmf2's GD layer  */
@@ -758,11 +771,15 @@ wmf_get_pixbuf (const gchar *filename,
   wmf_gd_t       *ddata = NULL;
   wmfAPI         *API   = NULL;
   wmfAPI_Options  api_options;
-  gint            file_width;
-  gint            file_height;
+  guint           file_width;
+  guint           file_height;
   wmfD_Rect       bbox;
   gint           *gd_pixels = NULL;
 
+  file = g_mapped_file_new (filename, FALSE, NULL);
+  if (! file)
+    return NULL;
+
   flags = WMF_OPT_IGNORE_NONFATAL | WMF_OPT_FUNCTION;
   api_options.function = wmf_gd_function;
 
@@ -773,7 +790,9 @@ wmf_get_pixbuf (const gchar *filename,
   ddata = WMF_GD_GetData (API);
   ddata->type = wmf_gd_image;
 
-  err = wmf_file_open (API, filename);
+  err = wmf_mem_open (API,
+                      (guchar *) g_mapped_file_get_contents (file),
+                      g_mapped_file_get_length (file));
   if (err != wmf_E_None)
     goto _wmf_error;
 
@@ -822,8 +841,6 @@ wmf_get_pixbuf (const gchar *filename,
   if (err != wmf_E_None)
     goto _wmf_error;
 
-  wmf_file_close (API);
-
   if (ddata->gd_image != NULL)
     gd_pixels = wmf_gd_image_pixels (ddata->gd_image);
   if (gd_pixels == NULL)
@@ -833,24 +850,27 @@ wmf_get_pixbuf (const gchar *filename,
   if (pixels == NULL)
     goto _wmf_error;
 
-  wmf_api_destroy (API);
-  API = NULL;
-
   *width = ddata->width;
   *height = ddata->height;
 
  _wmf_error:
   if (API)
-    wmf_api_destroy (API);
+    {
+      wmf_mem_close (API);
+      wmf_api_destroy (API);
+    }
+
+  g_mapped_file_free (file);
 
   return pixels;
 }
 
 static guchar *
 wmf_load_file (const gchar *filename,
-               gint        *width,
-               gint        *height)
+               guint       *width,
+               guint       *height)
 {
+  GMappedFile    *file;
   guchar         *pixels   = NULL;
 
   /* the bits we need to decode the WMF via libwmf2's GD layer  */
@@ -864,6 +884,10 @@ wmf_load_file (const gchar *filename,
 
   *width = *height = -1;
 
+  file = g_mapped_file_new (filename, FALSE, NULL);
+  if (! file)
+    return NULL;
+
   flags = WMF_OPT_IGNORE_NONFATAL | WMF_OPT_FUNCTION;
   api_options.function = wmf_gd_function;
 
@@ -874,7 +898,9 @@ wmf_load_file (const gchar *filename,
   ddata = WMF_GD_GetData (API);
   ddata->type = wmf_gd_image;
 
-  err = wmf_file_open (API, filename);
+  err = wmf_mem_open (API,
+                      (guchar *) g_mapped_file_get_contents (file),
+                      g_mapped_file_get_length (file));
   if (err != wmf_E_None)
     goto _wmf_error;
 
@@ -902,8 +928,6 @@ wmf_load_file (const gchar *filename,
   if (err != wmf_E_None)
     goto _wmf_error;
 
-  wmf_file_close (API);
-
   if (ddata->gd_image != NULL)
     gd_pixels = wmf_gd_image_pixels (ddata->gd_image);
   if (gd_pixels == NULL)
@@ -913,12 +937,14 @@ wmf_load_file (const gchar *filename,
   if (pixels == NULL)
     goto _wmf_error;
 
-  wmf_api_destroy (API);
-  API = NULL;
-
  _wmf_error:
   if (API)
-    wmf_api_destroy (API);
+    {
+      wmf_mem_close (API);
+      wmf_api_destroy (API);
+    }
+
+  g_mapped_file_free (file);
 
   return pixels;
 }
@@ -932,27 +958,26 @@ load_image (const gchar *filename)
   gint32        image;
   gint32	layer;
   GimpDrawable *drawable;
+  guchar       *pixels;
   GimpPixelRgn	pixel_rgn;
-  gchar        *status;
-  gint          i, rowstride;
+  guint         width, height;
+  guint         rowstride;
+  guint         count = 0;
+  guint         done  = 0;
+  gpointer      pr;
 
-  guchar       *pixels, *buf;
-  gint          width, height;
-
-  pixels = buf = wmf_load_file (filename, &width, &height);
+  pixels = wmf_load_file (filename, &width, &height);
   rowstride = width * 4;
 
   if (!pixels)
     {
       g_message (_("Could not open '%s' for reading."),
                  gimp_filename_to_utf8 (filename));
-      gimp_quit ();
+      return -1;
     }
 
-  status = g_strdup_printf (_("Opening '%s'..."),
-                            gimp_filename_to_utf8 (filename));
-  gimp_progress_init (status);
-  g_free (status);
+  gimp_progress_init_printf (_("Opening '%s'"),
+                             gimp_filename_to_utf8 (filename));
 
   image = gimp_image_new (width, height, GIMP_RGB);
   gimp_image_set_filename (image, filename);
@@ -966,18 +991,28 @@ load_image (const gchar *filename)
 
   drawable = gimp_drawable_get (layer);
 
-  gimp_tile_cache_ntiles ((width / gimp_tile_width ()) + 1);
+  gimp_pixel_rgn_init (&pixel_rgn, drawable, 0, 0, width, height, TRUE, FALSE);
 
-  gimp_pixel_rgn_init (&pixel_rgn, drawable, 0, 0,
-                       drawable->width, drawable->height, TRUE, FALSE);
-
-  for (i = 0; i < height; i++)
+  for (pr = gimp_pixel_rgns_register (1, &pixel_rgn);
+       pr != NULL;
+       pr = gimp_pixel_rgns_process (pr))
     {
-      gimp_pixel_rgn_set_row (&pixel_rgn, buf, 0, i, width);
-      buf += rowstride;
+      const guchar *src  = pixels + pixel_rgn.y * rowstride + pixel_rgn.x * 4;
+      guchar       *dest = pixel_rgn.data;
+      gint          y;
 
-      if (i % 100 == 0)
-        gimp_progress_update ((gdouble) i / (gdouble) height);
+      for (y = 0; y < pixel_rgn.h; y++)
+        {
+          memcpy (dest, src, pixel_rgn.w * pixel_rgn.bpp);
+
+          src  += rowstride;
+          dest += pixel_rgn.rowstride;
+        }
+
+      done += pixel_rgn.h * pixel_rgn.w;
+
+      if (count++ % 16 == 0)
+        gimp_progress_update ((gdouble) done / (width * height));
     }
 
   g_free (pixels);
@@ -986,7 +1021,7 @@ load_image (const gchar *filename)
 
   gimp_progress_update (1.0);
 
-  /* Tell the GIMP to display the image.
+  /* Tell GIMP to display the image.
    */
   gimp_image_add_layer (image, layer, 0);
   gimp_drawable_flush (drawable);
